**************
Stock Analyzer
**************

A Python package for analyzing stock patterns.

Installation
############
After running setup.py, configuration.ini will be created. Enter your TD Ameritrade developer API key here.

TD Ameritrade API
#################

You can create a free developer account and register for an API key `here <https://developer.tdameritrade.com/apis/>`_.